bowl package — bowl 0.2.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- bowl 0.2.0 documentation »

# bowl package

## Subpackages

- bowl.cli_opts package
  - Submodules
  - bowl.cli_opts.add module
  - bowl.cli_opts.connect module
  - bowl.cli_opts.delete module
  - bowl.cli_opts.disconnect module
  - bowl.cli_opts.hosts module
  - bowl.cli_opts.image_import module
  - bowl.cli_opts.images module
  - bowl.cli_opts.info module
  - bowl.cli_opts.kill module
  - bowl.cli_opts.link module
  - bowl.cli_opts.list module
  - bowl.cli_opts.login module
  - bowl.cli_opts.logout module
  - bowl.cli_opts.logs module
  - bowl.cli_opts.new module
  - bowl.cli_opts.remove module
  - bowl.cli_opts.repositories module
  - bowl.cli_opts.services module
  - bowl.cli_opts.snapshot module
  - bowl.cli_opts.snapshots module
  - bowl.cli_opts.start module
  - bowl.cli_opts.stop module
  - bowl.cli_opts.unlink module
  - bowl.cli_opts.update module
  - bowl.cli_opts.version module
  - Module contents

## Submodules

## bowl.api module

This module is the web server for running the REST API of bowl.

Created on 14 March 2014 @author: Charlie Lewis

class `bowl.api.` `api_add`

  This class is resposible for adding a service

  `POST`()

    POSTs the new service being added.

class `bowl.api.` `api_connect`

  This class is resposible for creating a connection to a docker host.

  `GET`(host)

    creates a connection to a new docker host.

class `bowl.api.` `api_delete`

  This class is resposible for deleting an image.

  `GET`(image)

    deletes the specified image.

class `bowl.api.` `api_disconnect`

  This class is resposible for disconnecting a connection to a docker host.

  `GET`(host)

    disconnects the specified docker host.

class `bowl.api.` `api_hosts`

  This class is resposible for listing the connected docker hosts.

  `GET`()

    GETs the connected docker hosts.

    Returns: | returns the list of connected docker hosts.

class `bowl.api.` `api_image_import`

  This class is resposible for importing an image.

  `POST`()

    POSTs the image being imported.

class `bowl.api.` `api_images`

  This class is resposible for listing the images.

  `GET`()

    GETs the images.

    Returns: | returns the list of images.

class `bowl.api.` `api_info`

  This class is resposible for giving system-wide information.

  `GET`()

    GETs the system-wide information and renders it.

    Returns: | returns the information.

class `bowl.api.` `api_kill`

  This class is resposible for killing a container.

  `GET`(container)

    the container to kill.

class `bowl.api.` `api_link`

  This class is resposible for linking a service repository host.

  `GET`(repository)

    creates a link to a new service repository.

class `bowl.api.` `api_list`

  This class is resposible for listing the running containers.

  `GET`()

    GETs the list of running containers.

    Returns: | returns the list of running containers.

class `bowl.api.` `api_login`

  This class is resposible for logging in.

  `POST`()

    POSTs the user to login.

class `bowl.api.` `api_logout`

  This class is resposible for logging out.

  `POST`()

    POSTs the user to logout.

class `bowl.api.` `api_logs`

  This class is resposible for returning logs of a server.

  `GET`()

    GETs the logs of a server.

    Returns: | returns the logs of a server.

class `bowl.api.` `api_new`

  This class is resposible for creating a new container.

  `POST`()

    POSTs the creation of a new container.

class `bowl.api.` `api_remove`

  This class is resposible for removing a container.

  `POST`()

    POSTs the removal of a container.

class `bowl.api.` `api_repo_services`

  This class is resposible for sending services to the client.

  `GET`()

    GETs the services and packages them up and serves them up as a static file.

  `make_tarfile`(output_filename, source_dir)

class `bowl.api.` `api_repositories`

  This class is resposible for listing the connected repositories.

  `GET`()

    GETs the connected repositories.

    Returns: | returns the list of connected repositories.

class `bowl.api.` `api_services`

  This class is resposible for listing services.

  `GET`()

    GETs the list of services.

class `bowl.api.` `api_snapshot`

  This class is resposible for snapshotting a container.

  `GET`(container)

    creates a snapshot of a container.

class `bowl.api.` `api_snapshots`

  This class is resposible for listing snapshots.

  `GET`()

    GETs the list of snapshots.

class `bowl.api.` `api_unlink`

  This class is resposible for unlinking a service repository host.

  `GET`(repository)

    unlinks the specified service repository.

class `bowl.api.` `api_uptime`

  This class is resposible for returning the uptime of the API server.

  `GET`()

    GETs the uptime of the API server.

    Returns: | returns the uptime of the API server.

class `bowl.api.` `api_version`

  This class is resposible for returning the version of bowl.

  `GET`()

    GETs the version of bowl.

    Returns: | returns the version of bowl.

class `bowl.api.` `main`(port=8080, host='0.0.0.0')

  Bases: `object`

  This class is responsible for initializing the urls and web server.

  `setup`()

class `bowl.api.` `root`

  This class is resposible for giving information about the rest server.

  `GET`()

    GETs the information about the rest server and renders it.

    Returns: | returns the information

## bowl.cli module

This module is the commandline interface of bowl.

Created on 14 March 2014 @author: Charlie Lewis

class `bowl.cli.` `cli`

  Bases: `object`

  This class is responsible for all commandline operations.

  `parse_args`()

`bowl.cli.` `main`()

## Module contents

### Navigation

- index
- modules |
- next |
- previous |
- bowl 0.2.0 documentation »